pub struct CombineReducers<R>(pub R);Expand description
Runs multiple reducers in order and merges their commands.
Tuple Fields
0: RTrait Implementations
Sourceimpl<R: Clone> Clone for CombineReducers<R>
impl<R: Clone> Clone for CombineReducers<R>
Sourcefn clone(&self) -> CombineReducers<R>
fn clone(&self) -> CombineReducers<R>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<R: Copy> Copy for CombineReducers<R>
Sourceimpl<R: Debug> Debug for CombineReducers<R>
impl<R: Debug> Debug for CombineReducers<R>
impl<R: Eq> Eq for CombineReducers<R>
Sourceimpl<R: PartialEq> PartialEq for CombineReducers<R>
impl<R: PartialEq> PartialEq for CombineReducers<R>
Sourcefn eq(&self, other: &CombineReducers<R>) -> bool
fn eq(&self, other: &CombineReducers<R>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<S, A, R1> Reducer for CombineReducers<(R1,)>
impl<S, A, R1> Reducer for CombineReducers<(R1,)>
Sourceimpl<S, A, R1, R2> Reducer for CombineReducers<(R1, R2)>
impl<S, A, R1, R2> Reducer for CombineReducers<(R1, R2)>
Sourceimpl<S, A, R1, R2, R3> Reducer for CombineReducers<(R1, R2, R3)>
impl<S, A, R1, R2, R3> Reducer for CombineReducers<(R1, R2, R3)>
Sourceimpl<S, A, R1, R2, R3, R4> Reducer for CombineReducers<(R1, R2, R3, R4)>
impl<S, A, R1, R2, R3, R4> Reducer for CombineReducers<(R1, R2, R3, R4)>
Sourceimpl<S, A, R1, R2, R3, R4, R5> Reducer for CombineReducers<(R1, R2, R3, R4, R5)>
impl<S, A, R1, R2, R3, R4, R5> Reducer for CombineReducers<(R1, R2, R3, R4, R5)>
Sourceimpl<S, A, R1, R2, R3, R4, R5, R6> Reducer for CombineReducers<(R1, R2, R3, R4, R5, R6)>
impl<S, A, R1, R2, R3, R4, R5, R6> Reducer for CombineReducers<(R1, R2, R3, R4, R5, R6)>
impl<R: PartialEq> StructuralPartialEq for CombineReducers<R>