Skip to main contentModule scope
Source - ForEachReducer
- Run a child reducer for each element in an
IdentifiedVec. - IfLetReducer
ifLet — run child reducer when optional state is Some; cancel on dismiss.- ScopeReducer
- Focuses nested state/action and runs a child reducer (UDF
Scope).
- lift_cmd
- Lift child command into parent action space and tag effects with a cancel id.
- lift_cmd_with_id
- Lift child command into parent action space with a per-id embed fn.
- IfCaseLetReducer
ifCaseLet — ifLet for enum-variant child state (same mechanics, enum-focused accessors).- OptionalReducer
optional — scope that no-ops when child state is absent (no dismiss/cancel).