macro_rules! total_update {
($state:expr, $action:expr, {
$($variant:pat => $body:expr,)*
_ => $default:expr
}) => { ... };
}Expand description
Match all variants of an action enum in update (exhaustive dispatch helper).
macro_rules! total_update {
($state:expr, $action:expr, {
$($variant:pat => $body:expr,)*
_ => $default:expr
}) => { ... };
}Match all variants of an action enum in update (exhaustive dispatch helper).