Module store

Module store 

Structs

ChangeSet
Which top-level (or derived) fields changed since the last signal.
ChangeSubscriber
Iterator-like subscription to field change signals (no full-state clone).
ScopedChangeSubscriber
Field change subscription focused to a scoped child store.
ScopedStateSubscriber
ScopedStore
Child store routing actions through a parent action casepath.
StateSubscriber
Iterator-like subscription to state snapshots.
Store
Cloneable dispatch handle for a running Runtime.
StoreTask
Awaitable handle for in-flight effects from a single Store::send.

Enums

StoreTaskError