Module test_runtime

Module test_runtime 

Macros

assert_effect
Assert that the last command contains an effect matching a predicate.

Structs

TestRuntime
Synchronous test runtime for asserting effect descriptions without Tokio.