pub struct ProjectedBinding<Root: 'static, Focus: 'static, SK> { /* private fields */ }Expand description
A field projected from a StateBinding through a keypath.
Implementations
Sourceimpl<Root, Focus, SK> ProjectedBinding<Root, Focus, SK>where
Root: 'static,
Focus: 'static,
SK: RefKpTrait<Root, Focus>,
impl<Root, Focus, SK> ProjectedBinding<Root, Focus, SK>where
Root: 'static,
Focus: 'static,
SK: RefKpTrait<Root, Focus>,
Sourcepub fn with<R>(&self, f: impl FnOnce(&Focus) -> R) -> Option<R>
pub fn with<R>(&self, f: impl FnOnce(&Focus) -> R) -> Option<R>
Borrow the focused value under the root lock, or None if the keypath misses.
Sourcepub fn with_mut<R>(&self, f: impl FnOnce(&mut Focus) -> R) -> Option<R>
pub fn with_mut<R>(&self, f: impl FnOnce(&mut Focus) -> R) -> Option<R>
Mutably borrow the focused value under the root lock, or None if the keypath misses.
Sourcepub fn project<V, SubSK>(
self,
sub_kp: SubSK,
) -> ComposedBinding<Root, Focus, V, SK, SubSK>where
SubSK: RefKpTrait<Focus, V>,
SK: Clone,
pub fn project<V, SubSK>(
self,
sub_kp: SubSK,
) -> ComposedBinding<Root, Focus, V, SK, SubSK>where
SubSK: RefKpTrait<Focus, V>,
SK: Clone,
Chain another keypath segment (consumes self; parent keypath must be Clone).